import re
from typing import Match, Optional

END_CHIEF_STYLE = r"""
    (?P<end_chief>
        \s*
        (
            ACTING|
            Acting|
            ACTG|
            Actg\.
        )?
        \s+
        C
        \.?
        \s* # possible space
        J
        \.?
        $ # end of string
    )
"""
END_CHIEF = re.compile(END_CHIEF_STYLE, re.X)

END_JUSTICE_STYLE = r"""
    (?P<end_justice>
        \s*
        \b # possible space
        (J|M)
        \.
        $ # end of string
    )
"""
END_JUSTICE = re.compile(END_JUSTICE_STYLE, re.X)

IS_JBL_STYLE = r"""
    \b
    j
    \s*
    \.?
    \s*
    b
    \s*
    \.?
    \s*
    l
    \s*
    \.?
    \s*
"""
IS_JBL = re.compile(IS_JBL_STYLE, re.I | re.X)


def text_has_justice_ender(raw: str) -> Optional[Match]:
    return END_CHIEF.search(raw) or END_JUSTICE.search(raw)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lawsql_cases_justices']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=6.0,<7.0',
 'Unidecode>=1.2.0,<2.0.0',
 'httpx>=0.22.0,<0.23.0',
 'lawsql_utils>=0.0.1,<0.0.2',
 'python-dotenv>=0.19.2,<0.20.0',
 'sqlite-utils>=3.22,<4.0']

setup_kwargs = {
    'name': 'lawsql-cases-justices',
    'version': '0.0.1',
    'description': 'Get justices from yaml file; updates local database.',
    'long_description': 'None',
    'author': 'Marcelino G. Veloso III',
    'author_email': 'mars@veloso.one',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



from .patterns import text_has_justice_ender


def remove_sr_jr_suffixes(raw: str) -> str:
    return raw.lower().removesuffix("sr.").removesuffix("jr.").strip(", ")


def remove_justice_enders(x: str) -> str:
    """Remove (if they exist) "J." and "C.J." ending texts which usually accompany ponente strings."""
    return x.removesuffix(m.group()) if (m := text_has_justice_ender(x)) else x


def get_surname(raw: str) -> str:
    """Remove suffiexes and J., C.J. ending texts to get the surame of the Justice."""
    raw = remove_justice_enders(raw)
    raw = remove_sr_jr_suffixes(raw)
    return raw.title()
